<?php
 /**
 * Jamroom Audio module
 *
 * copyright 2020 The Jamroom Network
 *
 * This Jamroom file is LICENSED SOFTWARE, and cannot be redistributed.
 *
 * This Source Code is subject to the terms of the Jamroom Network
 * Commercial License -  please see the included "license.html" file.
 *
 * This module may include works that are not developed by
 * The Jamroom Network
 * and are used under license - any licenses are included and
 * can be found in the "contrib" directory within this module.
 *
 * This software is provided "as is" and any express or implied
 * warranties, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose are
 * disclaimed.  In no event shall the Jamroom Network be liable for
 * any direct, indirect, incidental, special, exemplary or
 * consequential damages (including but not limited to, procurement
 * of substitute goods or services; loss of use, data or profits;
 * or business interruption) however caused and on any theory of
 * liability, whether in contract, strict liability, or tort
 * (including negligence or otherwise) arising from the use of this
 * software, even if advised of the possibility of such damage.
 * Some jurisdictions may not allow disclaimers of implied warranties
 * and certain statements in the above disclaimer may not apply to
 * you as regards implied warranties; the other terms and conditions
 * remain enforceable notwithstanding. In some jurisdictions it is
 * not permitted to limit liability and therefore such limitations
 * may not apply to you.
 *
 * @copyright 2012 Talldude Networks, LLC.
 * @author Brian Johnson <brian [at] jamroom [dot] net>
 */

// make sure we are not being called directly
defined('APP_DIR') or exit();

/**
 * meta
 */
function jrShoutcastPlayer_meta()
{
    return array(
        'name'        => 'ShoutcastPlayer',
        'url'         => 'sc_player',
        'version'     => '1.0.0',
        'developer'   => 'The Jamroom Network, &copy;' . strftime('%Y'),
        'description' => 'Create and stream Audio files such as songs and audio books',
        'doc_url'     => 'https://www.jamroom.net/the-jamroom-network/documentation/modules/273/audio',
        'category'    => 'custom',
        'requires'    => 'jrCore:6.5.3,jrSystemTools',
        'license'     => 'jcl'
    );
}

/**
 * init
 */
function jrShoutcastPlayer_init()
{
    // Tools
    // We provide support for the "audio" form field type
    jrCore_register_module_feature('jrCore', 'form_field', 'jrShoutcastPlayer', 'audio');
    jrCore_register_module_feature('jrCore', 'meta_data', 'jrShoutcastPlayer', 'extensions', 'aac,aif,flac,m4a,mp3,ogg,wav,wma');

    // CSS and JS
    jrCore_register_module_feature('jrCore', 'css', 'jrShoutcastPlayer', 'jrShoutcastPlayer.css');
    jrCore_register_module_feature('jrCore', 'css', 'jrShoutcastPlayer', 'animate.css');
    jrCore_register_module_feature('jrCore', 'css', 'jrShoutcastPlayer', 'bootstrap.min.css');
    jrCore_register_module_feature('jrCore', 'css', 'jrShoutcastPlayer', 'font-awesome.min.css');
    jrCore_register_module_feature('jrCore', 'javascript', 'jrShoutcastPlayer', 'popper.min.js');
    jrCore_register_module_feature('jrCore', 'javascript', 'jrShoutcastPlayer', 'bootstrap.min.js');
    jrCore_register_module_feature('jrCore', 'javascript', 'jrShoutcastPlayer', 'jrShoutcastPlayer.js');


    // Core module support
    jrCore_register_module_feature('jrCore', 'quota_support', 'jrShoutcastPlayer', 'on');
    // We listen for the jrUrlScan 'url_found' trigger and if its an audio url, add appropriate data to its array
    jrCore_register_event_listener('jrUrlScan', 'url_found', 'jrShoutcastPlayer_url_found_listener');
    jrCore_register_event_listener('jrUrlScan', 'url_player_params', 'jrShoutcastPlayer_url_player_params_listener');

    return true;
}

