<?php
 /**
 * Jamroom Audio module
 *
 * copyright 2020 The Jamroom Network
 *
 * This Jamroom file is LICENSED SOFTWARE, and cannot be redistributed.
 *
 * This Source Code is subject to the terms of the Jamroom Network
 * Commercial License -  please see the included "license.html" file.
 *
 * This module may include works that are not developed by
 * The Jamroom Network
 * and are used under license - any licenses are included and
 * can be found in the "contrib" directory within this module.
 *
 * This software is provided "as is" and any express or implied
 * warranties, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose are
 * disclaimed.  In no event shall the Jamroom Network be liable for
 * any direct, indirect, incidental, special, exemplary or
 * consequential damages (including but not limited to, procurement
 * of substitute goods or services; loss of use, data or profits;
 * or business interruption) however caused and on any theory of
 * liability, whether in contract, strict liability, or tort
 * (including negligence or otherwise) arising from the use of this
 * software, even if advised of the possibility of such damage.
 * Some jurisdictions may not allow disclaimers of implied warranties
 * and certain statements in the above disclaimer may not apply to
 * you as regards implied warranties; the other terms and conditions
 * remain enforceable notwithstanding. In some jurisdictions it is
 * not permitted to limit liability and therefore such limitations
 * may not apply to you.
 *
 * @copyright 2012 Talldude Networks, LLC.
 * @author Brian Johnson <brian [at] jamroom [dot] net>
 */

// make sure we are not being called directly
defined('APP_DIR') or exit();

/**
 * @param $_post
 * @param $_user
 * @param $_conf
 * @return bool|void
 */
function view_jrShoutcastPlayer_start($_post, $_user, $_conf) {
    // URL of SHOUTCast streaming
    //fdebug($_post);
    $url = $_conf['jrShoutcastPlayer_url'];
    // true or false to show history of played songs
    $historic = $_post['historic'] == 'true';
    // Type of streaming server used, shoutcast or icecast supported
    $streamingType = $_post['stream_type'];
    if(!empty($url)) {

        if($streamingType === 'shoutcast') {

            if($historic) {
                $urls[] = $url . '/7.html';
                $urls[] = $url . '/played';
                $curl = curl_multi_init();
                foreach($urls as $key => $value){
                    $ch[$key] = curl_init($value);
                    curl_setopt($ch[$key], CURLOPT_RETURNTRANSFER, true);
                    curl_setopt($ch[$key], CURLOPT_SSL_VERIFYPEER, false);
                    curl_setopt($ch[$key], CURLOPT_USERAGENT, 'Mozilla/5.0');
                    curl_multi_add_handle($curl, $ch[$key]);
                }
                do {
                    curl_multi_exec($curl, $running);
                    curl_multi_select($curl);
                } while ($running > 0);

                $content = array();
                foreach(array_keys($ch) as $key){
                    curl_multi_remove_handle($curl, $ch[$key]);
                    $content[] = curl_multi_getcontent($ch[$key]);
                }
                $data = $content[0];
                // Put the songs name between <music> tag
                $pagina = str_replace('</td><td>', '<music>', $content[1], $count);
                $playedSongs = explode('<music>', $pagina);
                // Remove unrelacionated content
                unset($playedSongs[0]);
                unset($playedSongs[1]);
                unset($playedSongs[2]);
                //fdebug($playedSongs);
                foreach($playedSongs as $song) {
                    fdebug($song);
                    // Get the name of the song
                    $cutStr = strpos($song, '</td></tr>');
                    $startStr = strpos($song, '</td></tr><tr><td>') + 18;
                    $playedSong = substr($song, 0, $cutStr);
                    $playedTime = substr($song, $startStr, 8);
                    // Separate artist from song
                    $songData = explode('-', $playedSong, 2);
                    $songNameHistoric = (!empty($songData[1])) ? trim($songData[1]) : '';
                    // Put in the principal array
                    $array['songHistory'][] = ['artist' => rtrim($songData[0]), 'song' => $songNameHistoric, 'time' => $playedTime];
                }
                curl_multi_close($curl);
            } else {
                $curl = curl_init($url . '/7.html');
                curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
                curl_setopt($curl, CURLOPT_USERAGENT, 'Mozilla/5.0');
                $data = curl_exec($curl);
                curl_close($curl);
            }

            if(!empty($data)) {
                $streamingData = explode(',', $data);
                $array['streamingId'] = $streamingData[1];
                $array['listenersMax'] = $streamingData[2];
                $array['listenersPeak'] = $streamingData[3];
                $array['listeners'] = $streamingData[4];
                $array['transmissionFrequency'] = $streamingData[5];
                $playingNow = $streamingData[6];
                // If there is a comma in the song name, join the following arrays
                if(count($streamingData) > 7) {
                    $playingNow = '';
                    for($i = 6; $i < count($streamingData); $i++) {
                        $playingNow .= ','.$streamingData[$i];
                    }
                }
                // Separate artist from song
                $currentSong = explode('-', $playingNow, 2);
                $artist = trim($currentSong[0]);
                if(substr($currentSong[0], 0, 1) === ',') {
                    $artist = substr($currentSong[0], 1, -1);
                }
                // Remover tags html da string
                if(count($currentSong) === 2) {
                    if(substr($currentSong[1], -14) === '</body></html>') {
                        $array['currentSong'] = (!empty($currentSong[1])) ? trim(substr($currentSong[1], 0, -14)) : '...';
                    } else {
                        $array['currentSong'] = (!empty($currentSong[1])) ? $currentSong[1] : '...';
                    }
                    $array['currentArtist'] = (empty($currentSong[1])) ? trim(substr($playingNow, 0, -14)) : $artist;
                }
                elseif(count($currentSong) < 2) {
                    $array['currentSong'] = (empty($playingNow) || $playingNow === '</body></html>') ? '...' : trim(substr($playingNow, 0, -14));
                    $array['currentArtist'] = '...';
                }
                else {
                    $array['currentSong'] = trim($currentSong[1]);
                    $array['currentArtist'] = trim($artist);
                }
            }
            else {
                $array = ['error' => 'Failed to fetch shoutcast data'];
            }
        }
        else if ($streamingType === 'icecast'){
            $url_explode = explode("/", $url);
            array_pop($url_explode);
            $url = implode("/", $url_explode);
            $url = $url."/status-json.xsl";
            // if cURL don't works, use file_get_contents
            // $curl = curl_init($url);
            // curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
            // curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
            // curl_setopt($curl, CURLOPT_USERAGENT, 'Mozilla/5.0');
            // $data = curl_exec($curl);
            // curl_close($curl);
            $data = file_get_contents($url);
            if(!empty($data)) {
                $ice_stats = json_decode($data, true);
                if(is_array($ice_stats["icestats"]["source"])) {
                    $ice_stats_source = $ice_stats["icestats"]["source"][0];
                } else {
                    $ice_stats_source = $ice_stats["icestats"]["source"];
                }
                $array['listenersPeak'] = $ice_stats_source["listener_peak"];
                $array['listeners'] = $ice_stats_source["listeners"];
                $array['transmissionFrequency'] = $ice_stats_source["bitrate"];
                $currently_playing = $ice_stats_source["title"];
                $currently_playing = explode(" - ", $currently_playing, 2);
                $array['currentSong'] = $currently_playing[1];
                $array['currentArtist'] = explode(";",$currently_playing[0])[0];
                // check if it is alredy in played songs and append if necessary
                $track_history = file("player.log");
                $track_list = array_slice($track_history, 0, 20);
                if (stripos($track_history[0], $currently_playing[0]." - ".$currently_playing[1]) === false){
                    array_unshift($track_list, $currently_playing[0]." - ".$currently_playing[1]."\n");
                    file_put_contents("player.log", $track_list);
                }
            } else {
                $array = ['error' => 'Failed to fetch icecast data'];
            }
            $track_history = file("player.log");
            // remove first element from history
            array_shift($track_history);
            if($historic) {
                $i = 0;
                foreach ($track_history as $line){
                    if($i > 4) continue;
                    $track = explode(" - ", $line, 2);
                    $last_artist = explode(";",$track[0])[0];
                    $last_song = str_replace(array("\n", "\r"), '', $track[1]);
                    $array['songHistory'][] = ['artist' => "$last_artist", 'song' => "$last_song"];
                    $i++;
                }
            }
        } else {
            $array = ['error' => 'STREAM_TYPE parameter not found'];
        }
    } else {
        $array = ['error' => 'URL parameter not found'];
    }
    fdebug($array);
    return jrCore_json_response($array);
}

/**
 * @param $_post
 * @param $_user
 * @param $_conf
 * @return mixed
 */
function view_jrShoutcastPlayer_popup($_post, $_user, $_conf) {
    return jrCore_parse_template('popup.tpl', array(), 'jrShoutcastPlayer');
}

/**
 * @param $_post
 * @param $_user
 * @param $_conf
 * @return bool|void
 */
function view_jrShoutcastPlayer_update($_post, $_user, $_conf) {
    jrCore_validate_location_url();
    if (!isset($_post['song']) || strlen($_post['song']) == 0) {
        return jrCore_json_response(array('error' => 'invalid song title'));
    }
    if (!isset($_post['profile_name']) || strlen($_post['song']) == 0) {
        return jrCore_json_response(array('error' => 'invalid profile name'));
    }
    // Get all audio files that are part of this album
    $_sp = array(
        'search'                       => array(
            "audio_title = {$_post['song']}",
           "profile_name = {$_post['profile_name']}"
		 // jake put in kod
         "audio_artist = {$_post['profile_name']}"
		  // SLUT JAKE
		  
		  
        ),
        'return_keys'                  => array('_item_id'),
        'exclude_jrUser_keys'          => true,
        'exclude_jrProfile_quota_keys' => true,
        'order_by'                     => array('_created' => 'numerical_asc'),
        'limit'                        => 1
    );
    $_rt = jrCore_db_search_items('jrAudio', $_sp);
    if (isset($_rt) && is_array($_rt)) {
        jrCore_db_increment_key('jrAudio',$_rt['_items'][0]['_item_id'],'audio_file_stream_count',1,true);
        return jrCore_json_response(array('success' => 1));
    }
    return jrCore_json_response(array('error' => 'update failed'));
}