/*
Jamroom Shoutcast Player
*/

var RADIO_NAME;
var URL;
var URL_STREAMING;
var STREAMING_TYPE;
var API_KEY;
var HISTORIC;
var DEFAULT_COVER_ART;
var audio;
var windowObjectReference = null;
let windowFeatures = "left=100,top=1,width=340,height=600";

// ShoutcastPlayer control
function ShoutcastPlayer() {
    this.play = async function () {
        await audio.play();
        var defaultVolume = document.getElementById('volume').value;
        if (typeof (Storage) !== 'undefined') {
            if (localStorage.getItem('volume') !== null) {
                audio.volume = jrShoutcastPlayer_intToDecimal(localStorage.getItem('volume'));
            } else {
                audio.volume = jrShoutcastPlayer_intToDecimal(defaultVolume);
            }
        } else {
            audio.volume = jrShoutcastPlayer_intToDecimal(defaultVolume);
        }
        document.getElementById('volIndicator').innerHTML = defaultVolume;
    };
    this.pause = function () {
        audio.pause();
    };
    this.changeTitlePage = function (title = RADIO_NAME) {
        document.title = title;
    };
    this.refreshCurrentSong = function (song, artist) {
        var currentSong = document.getElementById('currentSong');
        var currentArtist = document.getElementById('currentArtist');

        if (song !== currentSong.innerHTML) {
            // Animate transition
            currentSong.className = 'animated flipInY text-uppercase';
            currentSong.innerHTML = song;

            currentArtist.className = 'animated flipInY text-capitalize';
            currentArtist.innerHTML = artist;

            // Refresh modal title
            document.getElementById('lyricsSong').innerHTML = song + ' - ' + artist;

            // Remove animation classes
            setTimeout(function () {
                currentSong.className = 'text-uppercase';
                currentArtist.className = 'text-capitalize';
            }, 2000);
        }
    }
    this.refreshHistoric = function (info, n) {
        var $historicDiv = document.querySelectorAll('#historicSong article');
        var $songName = document.querySelectorAll('#historicSong article .music-info .song');
        var $artistName = document.querySelectorAll('#historicSong article .music-info .artist');
        var $songTime = document.querySelectorAll('#historicSong article .music-info .time');

        // Default cover art
        var urlCoverArt = DEFAULT_COVER_ART;

        // Get cover art for song history
        var f = function (d) {
            if (d) {
                var data = JSON.parse(d);
                var artworkUrl100 = (data.resultCount) ? data.results[0].artworkUrl100 : urlCoverArt;
                document.querySelectorAll('#historicSong article .cover-historic')[n].style.backgroundImage = 'url(' + artworkUrl100 + ')';
            }
            // Formating characters to UTF-8
            var music = info.song.replace(/&apos;/g, '\'');
            var songHist = music.replace(/&amp;/g, '&');

            var artist = info.artist.replace(/&apos;/g, '\'');
            var artistHist = artist.replace(/&amp;/g, '&');

            var time = info.time.replace(/&apos;/g, '\'');
            var timeHist = time.replace(/&amp;/g, '&');

            $songName[n].innerHTML = songHist;
            $artistName[n].innerHTML = artistHist;
            $songTime[n].innerHTML = timeHist;

            // Add class for animation
            $historicDiv[n].classList.add('animated');
            $historicDiv[n].classList.add('slideInRight');
        }
		
        // jake
		 // let url = 'https://music.apple.com/us/artist/search'
       let url = 'https://itunes.apple.com/search'
        let data = {'term':  info.artist, 'song' : info.song, 'media' : 'music', 'limit' : 1, 'true' : true};
        jrShoutcastPlayer_get_url(url, data, f);

        setTimeout(function () {
            for (var j = 0; j < 18; j++) {
                $historicDiv[j].classList.remove('animated');
                $historicDiv[j].classList.remove('slideInRight');
            }
        }, 3000);
    }
    this.refreshCover = function (song = '', artist) {
        // Default cover art
        var urlCoverArt = DEFAULT_COVER_ART;

        var f = function (d) {
            var coverArt = document.getElementById('currentCoverArt');
            var coverBackground = document.getElementById('bgCover');
            // Get cover art URL on iTunes API
            if (coverArt) {
                var data = JSON.parse(d);
                var artworkUrl100 = (data.resultCount) ? data.results[0].artworkUrl100 : urlCoverArt;

                // Se retornar algum dado, alterar a resolução da imagem ou definir a padrão
                urlCoverArt = (artworkUrl100 !== urlCoverArt) ? artworkUrl100.replace('100x100bb', '512x512bb') : urlCoverArt;
                var urlCoverArt96 = (artworkUrl100 !== urlCoverArt) ? urlCoverArt.replace('512x512bb', '96x96bb') : urlCoverArt;
                var urlCoverArt128 = (artworkUrl100 !== urlCoverArt) ? urlCoverArt.replace('512x512bb', '128x128bb') : urlCoverArt;
                var urlCoverArt192 = (artworkUrl100 !== urlCoverArt) ? urlCoverArt.replace('512x512bb', '192x192bb') : urlCoverArt;
                var urlCoverArt256 = (artworkUrl100 !== urlCoverArt) ? urlCoverArt.replace('512x512bb', '256x256bb') : urlCoverArt;
                var urlCoverArt384 = (artworkUrl100 !== urlCoverArt) ? urlCoverArt.replace('512x512bb', '384x384bb') : urlCoverArt;

                coverArt.style.backgroundImage = 'url(' + urlCoverArt + ')';
                coverArt.className = 'animated bounceInLeft';

                coverBackground.style.backgroundImage = 'url(' + urlCoverArt + ')';

                setTimeout(function () {
                    coverArt.className = '';
                }, 2000);

                if ('mediaSession' in navigator) {
                    navigator.mediaSession.metadata = new MediaMetadata({
                        title: song,
                        artist: artist,
                        artwork: [{
                            src: urlCoverArt96,
                            sizes: '96x96',
                            type: 'image/png'
                        },
                            {
                                src: urlCoverArt128,
                                sizes: '128x128',
                                type: 'image/png'
                            },
                            {
                                src: urlCoverArt192,
                                sizes: '192x192',
                                type: 'image/png'
                            },
                            {
                                src: urlCoverArt256,
                                sizes: '256x256',
                                type: 'image/png'
                            },
                            {
                                src: urlCoverArt384,
                                sizes: '384x384',
                                type: 'image/png'
                            },
                            {
                                src: urlCoverArt,
                                sizes: '512x512',
                                type: 'image/png'
                            }
                        ]
                    });
                }
            }
        }
		
		// jake 
		// let url = 'https://music.apple.com/us/artist/search'
      let url = 'https://itunes.apple.com/search'
        let data = {'term': artist, 'song' : song, 'media' : 'music', 'limit' : 1, 'true' : true};
        jrShoutcastPlayer_get_url(url, data, f);
    }
    this.changeVolumeIndicator = function (volume) {
        document.getElementById('volIndicator').innerHTML = volume;

        if (typeof (Storage) !== 'undefined') {
            localStorage.setItem('volume', volume);
        }
    }
    this.setVolume = function () {
        if (typeof (Storage) !== 'undefined') {
            var volumeLocalStorage = (!localStorage.getItem('volume')) ? 80 : localStorage.getItem('volume');
            document.getElementById('volume').value = volumeLocalStorage;
            document.getElementById('volIndicator').innerHTML = volumeLocalStorage;
        }
    }
    this.refreshLyric = function (currentSong, currentArtist) {
        var f = function (d) {
            if (d) {
                var data = JSON.parse(d);

                var openLyric = document.getElementsByClassName('lyrics')[0];

                if (data.type === 'exact' || data.type === 'aprox') {
                    var lyric = data.mus[0].text;

                    document.getElementById('lyric').innerHTML = lyric.replace(/\n/g, '<br />');
                    openLyric.style.opacity = "1";
                    openLyric.setAttribute('data-toggle', 'modal');
                } else {
                    openLyric.style.opacity = "0.3";
                    openLyric.removeAttribute('data-toggle');

                    var modalLyric = document.getElementById('modalLyrics');
                    modalLyric.style.display = "none";
                    modalLyric.setAttribute('aria-hidden', 'true');
                    (document.getElementsByClassName('modal-backdrop')[0]) ? document.getElementsByClassName('modal-backdrop')[0].remove(): '';
                }
            } else {
                document.getElementsByClassName('lyrics')[0].style.opacity = "0.3";
                document.getElementsByClassName('lyrics')[0].removeAttribute('data-toggle');
            }
        }

        let url = 'https://api.vagalume.com.br/search.php';
        let data = {'apikey': API_KEY, 'art' : currentArtist, 'mus' : currentSong.toLowerCase(), 'true' : true};
        jrShoutcastPlayer_get_url(url, data, f);
    }
    this.updateSongCount = function(currentSong, currentArtist) {
        var f = function(){}
        let url = core_system_url + '/' + jrShoutcastPlayer_url + '/update';
        let data = {'audio_title': currentSong, 'profile_name' : currentArtist};
        jrShoutcastPlayer_get_url(url, data, f);
    }
}
function jrShoutcastPlayer_togglePlay() {
    if (!audio.paused) {
        audio.pause();
    } else {
        audio.load();
        audio.play();
    }
}
function jrShoutcastPlayer_volumeUp() {
    var vol = audio.volume;
    if(audio) {
        if(audio.volume >= 0 && audio.volume < 1) {
            audio.volume = (vol + .01).toFixed(2);
        }
    }
}
function jrShoutcastPlayer_volumeDown() {
    var vol = audio.volume;
    if(audio) {
        if(audio.volume >= 0.01 && audio.volume <= 1) {
            audio.volume = (vol - .01).toFixed(2);
        }
    }
}
function jrShoutcastPlayer_mute() {
    if (!audio.muted) {
        document.getElementById('volIndicator').innerHTML = 0;
        document.getElementById('volume').value = 0;
        audio.volume = 0;
        audio.muted = true;
    } else {
        var localVolume = localStorage.getItem('volume');
        document.getElementById('volIndicator').innerHTML = localVolume;
        document.getElementById('volume').value = localVolume;
        audio.volume = jrShoutcastPlayer_intToDecimal(localVolume);
        audio.muted = false;
    }
}
function jrShoutcastPlayer_getStreamingData() {

    var f = function (d) {
        if(!d) {
            console.log('%cdebug', 'font-size: 22px')
        }
        let data = JSON.parse(d);
        var player = new ShoutcastPlayer();
        var currentSongElement = document.getElementById('currentSong').innerHTML.replace(/&apos;/g, '\'');
        let currentSongEl = currentSongElement.replace(/&amp;/g, '&');

        // Formating characters to UTF-8
        let song = data.currentSong || "error getting song";
        song = song.replace(/&apos;/g, '\'')
        let currentSong = song.replace(/&amp;/g, '&');
	// jake lagt till med blev fel
	//currentSong = CurrentSong.replace('  ', ' ');
    // slut jake
        let artist = data.currentArtist || "error gett artists";
        artist = artist.replace(/&apos;/g, '\'')
        let currentArtist = artist.replace(/&amp;/g, '&');
        currentArtist = currentArtist.replace('  ', ' ');

        // Change the title
        document.title = currentArtist + ' - ' + currentSong + ' | ' + RADIO_NAME;

        if (currentSongEl.trim() !== currentSong.trim()) {
            player.refreshCover(currentSong, currentArtist);
            player.refreshCurrentSong(currentSong, currentArtist);
            player.refreshLyric(currentSong, currentArtist);
            player.updateSongCount(currentSong, currentArtist);

            for (var i = 0; i < 18; i++) {
                player.refreshHistoric(data.songHistory[i], i);
            }
        }
    };

    var d = new Date();
    // Requisition with timestamp to prevent cache on mobile devices
    let url = core_system_url + '/' + jrShoutcastPlayer_url + '/start/';
    let data = {
        'stream_type' : STREAMING_TYPE,
        'historic' : HISTORIC,
        't' : d.getTime()
    };
    jrShoutcastPlayer_get_url(url, data, f);
}
function jrShoutcastPlayer_get_url(url, data, func) {
    $.ajax({
        url : url,
        type : 'GET',
        dataType : "html",
        cache : false,
        data : data,
        success : function(j){
            func(j);
        },
        error: function(){
            return false;
        }
    });
}
function jrShoutcastPlayer_expandHistory() {
    $('#player .container, #expand').toggleClass('expand');
    scrollTo({
        top: 0,
        left: 0,
        behavior: "smooth"
    })
}
function jrShoutcastPlayer_intToDecimal(vol) {
    return vol / 100;
}
function jrShoutcastPlayer_decimalToInt(vol) {
    return vol * 100;
}
function jrShoutcastPlayer_popup() {
    audio.pause()
    if(windowObjectReference == null || windowObjectReference.closed) {
        windowObjectReference = window.open(core_system_url + '/' + jrShoutcastPlayer_url +'/popup',
            "PromoteFirefoxWindowName", windowFeatures);
    }
    else {
        windowObjectReference.focus();
    }
}
function jrShoutcastPlayer_init() {
    var player = new ShoutcastPlayer();
    player.changeTitlePage();
    player.setVolume();
    player.play().then(r => null);
    jrShoutcastPlayer_getStreamingData();
    // Interval to get streaming data in miliseconds
    setInterval(function () {
        jrShoutcastPlayer_getStreamingData();
    }, 8000);
    var coverArt = document.getElementsByClassName('cover-album')[0];
    coverArt.style.height = coverArt.offsetWidth + 'px';
    // On play, change the button to pause
    audio.onplay = function () {
        var botao = document.getElementById('playerButton');

        if (botao.className === 'fa fa-play') {
            botao.className = 'fa fa-pause';
        }
    }
    // On pause, change the button to play
    audio.onpause = function () {
        var botao = document.getElementById('playerButton');

        if (botao.className === 'fa fa-pause') {
            botao.className = 'fa fa-play';
        }
    }
    // Unmute when volume changed
    audio.onvolumechange = function () {
        if (audio.volume > 0) {
            audio.muted = false;
        }
        var mute =  $('#jrShoutcastPlayer_mute');
        mute.removeClass('fa-volume-off').removeClass('fa-volume-down').removeClass('fa-volume').removeClass('fa-volume-up')
        if (audio.volume > 0.5) {
            mute.addClass('fa-volume-up');
        } else if (audio.volume > 0) {
            mute.addClass('fa-volume-down');
        } else {
            mute.addClass('fa-volume-off');
        }
    }
    audio.onerror = function () {
        var confirmation = confirm('Error on communicate to server. \nClick OK to try again.');

        if (confirmation) {
            window.location.reload();
        }
    }
    document.getElementById('volume').oninput = function () {
        audio.volume = jrShoutcastPlayer_intToDecimal(this.value);
        var player = new ShoutcastPlayer();
        player.changeVolumeIndicator(this.value);
    }
    document.getElementById('jrShoutcastPlayer_mute').onclick = function() {
        jrShoutcastPlayer_mute();
    }
    document.getElementById('expand').onclick  = function() {
        jrShoutcastPlayer_expandHistory();
    };
    document.getElementById('popup').onclick = function() {
        jrShoutcastPlayer_popup();
    }
    // ShoutcastPlayer control by keys
    document.addEventListener('keydown', function (key) {

        var slideVolume = document.getElementById('volume');

        var page = new ShoutcastPlayer();
        switch (key) {
            // Arrow up
            case 38:
                jrShoutcastPlayer_volumeUp();
                slideVolume.value = jrShoutcastPlayer_decimalToInt(audio.volume);
                player.changeVolumeIndicator(jrShoutcastPlayer_decimalToInt(audio.volume));
                break;
            // Arrow down
            case 40:
                jrShoutcastPlayer_volumeDown();
                slideVolume.value = jrShoutcastPlayer_decimalToInt(audio.volume);
                player.changeVolumeIndicator(jrShoutcastPlayer_decimalToInt(audio.volume));
                break;
            // Spacebar
            case 32:
                jrShoutcastPlayer_togglePlay();
                break;
            // P
            case 80:
                jrShoutcastPlayer_togglePlay();
                break;
            // M
            case 77:
                jrShoutcastPlayer_mute();
                break;
            // 0
            case 48:
                audio.volume = 0;
                slideVolume.value = 0;
                player.changeVolumeIndicator(0);
                break;
            // 0 numeric keyboard
            case 96:
                audio.volume = 0;
                slideVolume.value = 0;
                player.changeVolumeIndicator(0);
                break;
            // 1
            case 49:
                audio.volume = .1;
                slideVolume.value = 10;
                player.changeVolumeIndicator(10);
                break;
            // 1 numeric key
            case 97:
                audio.volume = .1;
                slideVolume.value = 10;
                player.changeVolumeIndicator(10);
                break;
            // 2
            case 50:
                audio.volume = .2;
                slideVolume.value = 20;
                player.changeVolumeIndicator(20);
                break;
            // 2 numeric key
            case 98:
                audio.volume = .2;
                slideVolume.value = 20;
                player.changeVolumeIndicator(20);
                break;
            // 3
            case 51:
                audio.volume = .3;
                slideVolume.value = 30;
                player.changeVolumeIndicator(30);
                break;
            // 3 numeric key
            case 99:
                audio.volume = .3;
                slideVolume.value = 30;
                player.changeVolumeIndicator(30);
                break;
            // 4
            case 52:
                audio.volume = .4;
                slideVolume.value = 40;
                player.changeVolumeIndicator(40);
                break;
            // 4 numeric key
            case 100:
                audio.volume = .4;
                slideVolume.value = 40;
                player.changeVolumeIndicator(40);
                break;
            // 5
            case 53:
                audio.volume = .5;
                slideVolume.value = 50;
                player.changeVolumeIndicator(50);
                break;
            // 5 numeric key
            case 101:
                audio.volume = .5;
                slideVolume.value = 50;
                player.changeVolumeIndicator(50);
                break;
            // 6
            case 54:
                audio.volume = .6;
                slideVolume.value = 60;
                player.changeVolumeIndicator(60);
                break;
            // 6 numeric key
            case 102:
                audio.volume = .6;
                slideVolume.value = 60;
                player.changeVolumeIndicator(60);
                break;
            // 7
            case 55:
                audio.volume = .7;
                slideVolume.value = 70;
                page.changeVolumeIndicator(70);
                break;
            // 7 numeric key
            case 103:
                audio.volume = .7;
                slideVolume.value = 70;
                player.changeVolumeIndicator(70);
                break;
            // 8
            case 56:
                audio.volume = .8;
                slideVolume.value = 80;
                player.changeVolumeIndicator(80);
                break;
            // 8 numeric key
            case 104:
                audio.volume = .8;
                slideVolume.value = 80;
                player.changeVolumeIndicator(80);
                break;
            // 9
            case 57:
                audio.volume = .9;
                slideVolume.value = 90;
                player.changeVolumeIndicator(90);
                break;
            // 9 numeric key
            case 105:
                audio.volume = .9;
                slideVolume.value = 90;
                player.changeVolumeIndicator(90);
                break;
        }
    });
}